from PyQt5 import QtGui, QtCore, QtWidgets
import sys


# ------------------------------------------------------------------------------
# |                                                                            |
# ------------------------------------------------------------------------------
class Window(QtWidgets.QMainWindow):
    def __init__(self):
        super().__init__()

        self.setGeometry(500, 400, 600, 400)
        self.setStyleSheet('QPlainTextEdit {font-family: Consolas; font-size: 22px;}')

        self.editor = Editor()
        self.setCentralWidget(self.editor)
        self.show()

    def keyPressEvent(self, event):
        if event.key() == QtCore.Qt.Key_Q and int(event.modifiers()) == QtCore.Qt.CTRL:
            self.close()    


# ------------------------------------------------------------------------------
# |                                                                            |
# ------------------------------------------------------------------------------
class Editor(QtWidgets.QPlainTextEdit):
    def __init__(self):
        super().__init__()

        self.setPlainText('abc')

        self.textChanged.connect(self.text_changed)
        self.cursorPositionChanged.connect(self.cursor_position_changed)
        
        self.previous_text = self.toPlainText()
        self.previous_position = self.textCursor().position()


    def text_changed(self):
        print(f'--- text changed ---')
        print(f'  Previous:  {repr(self.previous_text)} / pos = {self.previous_position}')
        print(f'  Current:   {repr(self.toPlainText())} / pos = {self.textCursor().position()}')

        self.previous_text = self.toPlainText()
        self.previous_position = self.textCursor().position()

    def cursor_position_changed(self):
        print(f'--- cursor position changed ---')
        print(f'  Previous:  {self.previous_position}')
        print(f'  Current:   {self.textCursor().position()}')
        self.previous_position = self.textCursor().position()



# ------------------------------------------------------------------------------
# |                                                                            |
# ------------------------------------------------------------------------------
if __name__ == '__main__':
    app = QtWidgets.QApplication(sys.argv)
    gui = Window()
    sys.exit(app.exec_())

